Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/js
diff options
context:
space:
mode:
authorBryan Berry <bryan@olenepal.org>2009-12-15 06:06:25 (GMT)
committer Bryan Berry <bryan@olenepal.org>2009-12-15 06:06:25 (GMT)
commitf401a66195fb51ec7764c728a8bab8f64232d4ac (patch)
tree747f07fbafa71351d2ee73cbb4d878eeb7dbae7d /js
parent9141e47204f65dfbabbb00798190bfff478fd91e (diff)
added test for Karma.kVideo
Diffstat (limited to 'js')
-rwxr-xr-xjs/karma.js7
1 files changed, 5 insertions, 2 deletions
diff --git a/js/karma.js b/js/karma.js
index 22c28a1..5d5c828 100755
--- a/js/karma.js
+++ b/js/karma.js
@@ -759,7 +759,7 @@ Karma.kAudio = {
};
/** NYI:Prototypal object for Video files
* @class This object is the prototype for video files
* @ throws {Error} if the individual audio asset is set to be localized but
* the globale locale is not set on the Karma.karma object
* @ throws {Error} if the name and file properties are not supplied
@@ -789,6 +789,10 @@ Karma.kVideo = {
_type : "video",
//initializes kVideo instance with values provided by user
_init : function (video) {
+ //Not Yet Implemented
+ Karma.karma._counters.errors++;
+ throw new Error("Video is not Yet Implemented");
+
video._localized = video._localized || false;
Karma.karma._counters.total++;
@@ -1112,7 +1116,6 @@ Karma.kSvg = {
function (e) {
that.doc = that.node.getSVGDocument();
that.root = that.doc.documentElement;
- console.log('foo');
Karma.karma._counters.loaded++;
Karma.karma._updateStatus();
that.status = "loaded";
@@ -759,7 +759,7 @@ Karma.kAudio = {
};
/** NYI:Prototypal object for Video files
- * @class This object is the prototype for video files
+ * @class Not Yet Implemented:This object is the prototype for video files
* @ throws {Error} if the individual audio asset is set to be localized but
* the globale locale is not set on the Karma.karma object